@@ -22,7 +22,7 @@ predictEventProb.matrix <- function(object,newdata,times,...){
 }
 
 predictEventProb.prodlim <- function(object,newdata,times,cause,...){
-  require(prodlim)
+  ## require(prodlim)
   p <- predict(object=object,cause=cause,type="cuminc",newdata=newdata,times=times,mode="matrix",level.chaos=1)
   ## if the model has no covariates
   ## then all cases get the same prediction
@@ -76,7 +76,6 @@ predictEventProb.CauseSpecificCox <- function (object, newdata, times, cause, ..
   N <- NROW(newdata)
   NC <- length(object$model)
   eTimes <- object$eventTimes
-  ## browser()
   if (missing(cause))
     cause <- object$theCause
   causes <- object$causes
@@ -112,7 +111,7 @@ predictEventProb.CauseSpecificCox <- function (object, newdata, times, cause, ..
 
 predictEventProb.rfsrc <- function(object, newdata, times, cause, ...){
   if (missing(cause)) stop("missing cause")
-  ptemp <- predict(object,newdata=newdata,...)$cif[,,cause]
+  ptemp <- predict(object,newdata=newdata,importance="none",...)$cif[,,cause]
   pos <- sindex(jump.times=object$time.interest,eval.times=times)
   p <- cbind(0,ptemp)[,pos+1]
   if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
@@ -120,6 +119,37 @@ predictEventProb.rfsrc <- function(object, newdata, times, cause, ...){
   p
 }
 
+coxboost <- function(formula,data,...){
+  ## require(CoxBoost)
+  call <- match.call()
+  formula <- eval(call$formula)
+  mf <- model.frame(formula,data)
+  resp <- model.response(mf)
+  Time <- as.numeric(resp[,"time"])
+  Status <- as.numeric(resp[,"event"])
+  cov <- as.matrix(mf[,-1])
+  cb <- CoxBoost::CoxBoost(time=Time,status=Status,x=cov,...)    
+  out <- list(coxboost=cb,call=call,covID=cb$xnames)
+  class(out) <- "coxboost"
+  out
+}
+
+predictEventProb.coxboost <- function(object,newdata,times,cause,...){
+  if (missing(cause)) stop("missing cause")
+  if (cause!=1) stop("CoxBoost can only predict cause 1")
+  newcova <- as.matrix(newdata[,object$covID])
+  p <- predict(object[[1]],newdata=newcova,times=times,type="CIF")
+  if (is.null(dim(p))) {
+    if (length(p)!=length(times))
+      stop("Prediction failed")
+  }
+  else{
+    if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
+      stop("Prediction failed")
+  }
+  p
+}
+
 ## predictUpdateProb.CSC <- function (object, newdata,times,horizon, cause, ...) {
   ## survtype <- object$survtype
   ## N <- NROW(newdata)
